@@ -2,6 +2,8 @@
  * Audio frame
  */
 
+#define AUDIO_TIMEBASE 1000000U
+
 /**
  * Defines a frame of audio samples
  */
@@ -42,3 +44,4 @@ static inline void auframe_update(struct auframe *af, void *sampv,
 size_t auframe_size(const struct auframe *af);
 void   auframe_mute(struct auframe *af);
 double auframe_level(struct auframe *af);
+uint64_t auframe_bytes_to_timestamp(const struct auframe *af, size_t n);
